Package {rjd3xjars}


Type: Package
Title: Interface to 'JDemetra+ 3.x' Time Series Analysis Software
Version: 0.1.1
Description: R Interface to 'JDemetra+ 3.x' (https://github.com/jdemetra) time series analysis software. It provides functions allowing to decompose a time series, including high-frequency data with multiple periodicities.
License: EUPL version 1.1 | EUPL version 1.2 [expanded from: EUPL]
URL: https://github.com/rjdverse/rjd3xjars
BugReports: https://github.com/rjdverse/rjd3xjars/issues
Depends: R (≥ 4.1.0)
Imports: rJava (≥ 1.0-6), rjd3jars (≥ 0.0.5)
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
SystemRequirements: Java (>= 21)
Collate: 'rjd3xjars-package.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-07-08 13:16:55 UTC; onyxia
Author: Jean Palate [aut], Tanguy Barthelemy [aut, cre]
Maintainer: Tanguy Barthelemy <tanguy.barthelemy@insee.fr>
Repository: CRAN
Date/Publication: 2026-07-08 13:30:02 UTC

rjd3xjars: Interface to 'JDemetra+ 3.x' Time Series Analysis Software

Description

R Interface to 'JDemetra+ 3.x' (https://github.com/jdemetra) time series analysis software. It provides functions allowing to decompose a time series, including high-frequency data with multiple periodicities.

Author(s)

Maintainer: Tanguy Barthelemy tanguy.barthelemy@insee.fr

Authors:

See Also

Useful links: