| Type: | Package |
| Title: | R Interface to 'JDemetra+ 3.x' Time Series Analysis Software |
| Version: | 0.1.0 |
| Description: | R Interface to 'JDemetra+ 3.x' (https://github.com/jdemetra) time series analysis software. It provides functions allowing to decompose a time series, including high-frequency data with multiple periodicities. |
| Depends: | R (≥ 4.1.0) |
| Imports: | rJava (≥ 1.0-6), rjd3toolkit (≥ 3.7.1) |
| SystemRequirements: | Java (>= 21) |
| License: | EUPL version 1.1 | EUPL version 1.2 [expanded from: EUPL] |
| URL: | https://github.com/rjdverse/rjd3xjars |
| Suggests: | knitr, rmarkdown |
| RoxygenNote: | 7.3.3 |
| BugReports: | https://github.com/rjdverse/rjd3xjars/issues |
| Encoding: | UTF-8 |
| Collate: | 'rjd3xjars-package.R' 'zzz.R' |
| NeedsCompilation: | no |
| Packaged: | 2026-04-14 13:37:02 UTC; onyxia |
| Author: | Jean Palate [aut], Tanguy Barthelemy [aut, cre] |
| Maintainer: | Tanguy Barthelemy <tanguy.barthelemy@insee.fr> |
| Repository: | CRAN |
| Date/Publication: | 2026-04-21 09:02:11 UTC |
rjd3xjars: R Interface to 'JDemetra+ 3.x' Time Series Analysis Software
Description
R Interface to 'JDemetra+ 3.x' (https://github.com/jdemetra) time series analysis software. It provides functions allowing to decompose a time series, including high-frequency data with multiple periodicities.
Author(s)
Maintainer: Tanguy Barthelemy tanguy.barthelemy@insee.fr
Authors:
Jean Palate palatejean@gmail.com
See Also
Useful links: